@@ -12,6 +12,10 @@ from inspect import ismethod
 from inspect import ismethoddescriptor
 from inspect import ismodule
 from inspect import isroutine
+try:
+    from types import InstanceType
+except ImportError:
+    InstanceType = None
 from functools import partial
 from logging import getLogger
 
@@ -36,7 +40,7 @@ except ImportError:
 
 
 __all__ = 'weave', 'Aspect', 'Proceed', 'Return', 'ALL_METHODS', 'NORMAL_METHODS'
-__version__ = '1.2.0'
+__version__ = '1.2.1'
 
 logger = getLogger(__name__)
 logdebug = logf(logger.debug)
@@ -484,7 +488,7 @@ def weave(target, aspects, **options):
         return weave_class(target, aspects, **options)
     elif ismodule(target):
         return weave_module(target, aspects, **options)
-    elif type(target).__module__ not in ('builtins', '__builtin__'):
+    elif type(target).__module__ not in ('builtins', '__builtin__') or InstanceType and isinstance(target, InstanceType):
         return weave_instance(target, aspects, **options)
     else:
         raise UnsupportedType("Can't weave object %s of type %s" % (target, type(target)))
@@ -675,33 +679,36 @@ def patch_module(module, name, replacement, original=UNSPECIFIED, aliases=True,
     seen = False
     original = getattr(module, name) if original is UNSPECIFIED else original
     location = module.__name__ if hasattr(module, '__name__') else type(module).__module__
+    target = module.__name__ if hasattr(module, '__name__') else type(module).__name__
     try:
         replacement.__module__ = location
     except (TypeError, AttributeError):
         pass
     for alias in dir(module):
+        logdebug("alias:%s (%s)", alias, name)
         if hasattr(module, alias):
             obj = getattr(module, alias)
+            logdebug("- %s:%s (%s)", obj, original, obj is original)
             if obj is original:
                 if aliases or alias == name:
-                    logdebug("= saving %s on %s.%s ...", replacement, location, alias)
+                    logdebug("= saving %s on %s.%s ...", replacement, target, alias)
                     setattr(module, alias, replacement)
                     rollback.merge(lambda alias=alias: setattr(module, alias, original))
                 if alias == name:
                     seen = True
             elif alias == name:
                 if ismethod(obj):
-                    logdebug("= saving %s on %s.%s ...", replacement, location, alias)
+                    logdebug("= saving %s on %s.%s ...", replacement, target, alias)
                     setattr(module, alias, replacement)
                     rollback.merge(lambda alias=alias: setattr(module, alias, original))
                 else:
-                    raise AssertionError("%s.%s = %s is not %s." % (location, alias, obj, original))
+                    raise AssertionError("%s.%s = %s is not %s." % (module, alias, obj, original))
 
     if not seen:
         warnings.warn('Setting %s.%s to %s. There was no previous definition, probably patching the wrong module.' % (
-            location, name, replacement
+            target, name, replacement
         ))
-        logdebug("= saving %s on %s.%s ...", replacement, location, name)
+        logdebug("= saving %s on %s.%s ...", replacement, target, name)
         setattr(module, name, replacement)
         rollback.merge(lambda: setattr(module, name, original))
     return rollback
