@@ -297,21 +297,21 @@ def test_story_text_helpers():
         test_mod.func(5)
         test_mod.target(1)
 
-    print (replay.missing())
-    assert replay.missing() == """stuff_1.meth('b') == 'y'  # returns
+    print (replay.missing)
+    assert replay.missing == """stuff_1.meth('b') == 'y'  # returns
 stuff_2 = test_pkg1.test_pkg2.test_mod.Stuff(2, 3)
 stuff_2.meth('c') == 'z'  # returns
 test_pkg1.test_pkg2.test_mod.target(2) == 3  # returns
 """
-    print (replay.unexpected())
-    assert replay.unexpected() == """stuff_1.meth() == None  # returns
+    print (replay.unexpected)
+    assert replay.unexpected == """stuff_1.meth() == None  # returns
 stuff_2 = test_pkg1.test_pkg2.test_mod.Stuff(4, 4)
 stuff_2.meth() == None  # returns
 test_pkg1.test_pkg2.test_mod.func(5) == None  # returns
 """
-    print (replay.diff())
+    print (replay.diff)
     if PY26:
-        assert replay.diff() == """--- expected """ """
+        assert replay.diff == """--- expected """ """
 +++ actual """ """
 @@ -1,7 +1,7 @@
  stuff_1 = test_pkg1.test_pkg2.test_mod.Stuff(1, 2)
@@ -327,7 +327,7 @@ test_pkg1.test_pkg2.test_mod.func(5) == None  # returns
 -test_pkg1.test_pkg2.test_mod.target(2) == 3  # returns
 """
     else:
-        assert replay.diff() == """--- expected
+        assert replay.diff == """--- expected
 +++ actual
 @@ -1,7 +1,7 @@
  stuff_1 = test_pkg1.test_pkg2.test_mod.Stuff(1, 2)
@@ -363,10 +363,10 @@ def test_story_empty_play_proxy_class_missing_report():
         obj.meth()
         obj.mix(10)
 
-    print(repr(replay.diff()))
+    print(repr(replay.diff))
 
     if PY26:
-        assert replay.diff() == """--- expected """ """
+        assert replay.diff == """--- expected """ """
 +++ actual """ """
 @@ -1,0 +1,18 @@
 +stuff_1 = test_pkg1.test_pkg2.test_mod.Stuff(1, 2)
@@ -389,7 +389,7 @@ def test_story_empty_play_proxy_class_missing_report():
 +that_long_stuf_3.mix(10) == (2, 10)  # returns
 """
     else:
-        assert replay.diff() == """--- expected
+        assert replay.diff == """--- expected
 +++ actual
 @@ -0,0 +1,18 @@
 +stuff_1 = test_pkg1.test_pkg2.test_mod.Stuff(1, 2)
@@ -466,7 +466,7 @@ def test_story_half_play_proxy_class():
         assert obj.mix(3, 4) == (0, 1, 3, 4)
 
         raises(TypeError, obj.meth, 123)
-    assert replay.unexpected() == format_calls(OrderedDict([
+    assert replay.unexpected == format_calls(OrderedDict([
         (('stuff_1', 'meth', '', ''), _Returns('None')),
         (('stuff_1', 'meth', '123', ''), _Raises(repr_ex(TypeError(
             'meth() takes exactly 1 argument (2 given)' if PY2 else
@@ -492,7 +492,7 @@ def test_story_full_play_noproxy():
         assert test_mod.target(123) == 'foobar'
         raises(ValueError, test_mod.target, 1234)
 
-    assert replay.unexpected() == ""
+    assert replay.unexpected == ""
 
 
 def test_story_full_play_noproxy_dump():
@@ -505,7 +505,7 @@ def test_story_full_play_noproxy_dump():
         assert test_mod.target(123) == 'foobar'
         raises(ValueError, test_mod.target, 1234)
 
-    assert replay.unexpected() == ""
+    assert replay.unexpected == ""
 
 
 def test_story_full_play_proxy():
@@ -519,7 +519,7 @@ def test_story_full_play_proxy():
         raises(ValueError, test_mod.target, 1234)
         raises(TypeError, test_mod.target, 'asdf')
 
-    assert replay.unexpected() == format_calls(OrderedDict([
+    assert replay.unexpected == format_calls(OrderedDict([
         ((None, 'test_pkg1.test_pkg2.test_mod.target', '', ''), _Returns("None")),
         ((None, 'test_pkg1.test_pkg2.test_mod.target', "'asdf'", ''), _Raises(repr_ex(TypeError(
             'target() takes no arguments (1 given)'
@@ -578,6 +578,6 @@ def xtest_story_empty_play_proxy_class_dependencies():
         other = obj.other(2)
         other.mix(3, 4)
 
-    print(repr(replay.diff()))
+    print(repr(replay.diff))
 
-    assert replay.diff() == ""
+    assert replay.diff == ""
