@@ -14,6 +14,8 @@ a = 1
 
 class Stuff(object):
     def __init__(self, *args):
+        if args == ('error',):
+            raise ValueError
         self.args = args
 
     def meth(self):
@@ -21,10 +23,14 @@ class Stuff(object):
 
     def mix(self, *args):
         self.meth()
-        return self.args + args
+        return getattr(self, 'args', ()) + args
 
     def raises(self, *a):
         raise ValueError(a)
 
+    def other(self, *args):
+        return ThatLONGStuf(*self.args + args)
+
+
 class ThatLONGStuf(Stuff):
     pass
